@@ -30,13 +30,15 @@ def run_action_on_object(brw, res, e, obj, checkfilterpassed_callback=None):
 	if e.get('action') == 'store_text': res[e.get('action_parameters')] = obj.text
 	if e.get('action') == 'foreach':
 		res['list'] = []
-		sub_brws = brw.find_elements_by_class_name(e.get('class_name'))
+		if not e.get('class_name') is None: sub_brws = brw.find_elements_by_class_name(e.get('class_name'))
+		if not e.get('name') is None: sub_brws = brw.find_elements_by_name(e.get('name'))
 		for sub_brw in sub_brws:
 			sub_res = {}
 			for s in e.get('action_parameters'):
 				brw_obj = sub_brw
 				if s.get('context') == 'whole_page': brw_obj = brw
-				sub_obj = brw_obj.find_element_by_class_name(s.get('class_name'))
+				if not s.get('class_name') is None: sub_obj = brw_obj.find_element_by_class_name(s.get('class_name'))
+				if not s.get('name') is None: sub_obj = brw_obj.find_element_by_name(s.get('name'))
 				sub_res = run_action_on_object(brw_obj, sub_res, s, sub_obj)
 			res['list'].append(sub_res)
 	return res
@@ -49,8 +51,12 @@ def run_process(brw, url_home, to, p, backtohome_begin=True, backtohome_end=True
 	for e in p:
 		obj = None
 		if e.get('filter') != None and not checkfilterpassed_callback(e.get('filter')): continue
-		if e.get('index') is None: obj = brw.find_element_by_class_name(e.get('class_name'))
-		else: obj = brw.find_elements_by_class_name(e.get('class_name'))[e.get('index')]
+		if e.get('index') is None:
+			if not e.get('class_name') is None: obj = brw.find_element_by_class_name(e.get('class_name'))
+			if not e.get('name') is None: obj = brw.find_element_by_name(e.get('name'))
+		else:
+			if not e.get('class_name') is None: obj = brw.find_elements_by_class_name(e.get('class_name'))[e.get('index')]
+			if not e.get('name') is None: obj = brw.find_elements_by_name(e.get('name'))[e.get('index')]
 		res = run_action_on_object(brw, res, e, obj, checkfilterpassed_callback)
 		if not e.get('sleep') is None: time.sleep(e.get('sleep'))
 	if backtohome_end:
